"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .state import State
from datetime import datetime
from owasp_nest.types import BaseModel
from typing_extensions import TypedDict


class IssueSchemaTypedDict(TypedDict):
    r"""Schema for Issue."""

    body: str
    created_at: datetime
    title: str
    state: State
    updated_at: datetime
    url: str


class IssueSchema(BaseModel):
    r"""Schema for Issue."""

    body: str

    created_at: datetime

    title: str

    state: State

    updated_at: datetime

    url: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .memberschema import MemberSchema, MemberSchemaTypedDict
from owasp_nest.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PagedMemberSchemaTypedDict(TypedDict):
    items: List[MemberSchemaTypedDict]
    count: int


class PagedMemberSchema(BaseModel):
    items: List[MemberSchema]

    count: int



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from owasp_nest.types import BaseModel
from typing_extensions import TypedDict


class CommitteeSchemaTypedDict(TypedDict):
    r"""Schema for Committee."""

    name: str
    description: str
    created_at: datetime
    updated_at: datetime


class CommitteeSchema(BaseModel):
    r"""Schema for Committee."""

    name: str

    description: str

    created_at: datetime

    updated_at: datetime



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import httpx
from owasp_nest.models import NestError
from owasp_nest.types import BaseModel
from typing import Optional


class ChapterErrorResponseData(BaseModel):
    message: str


class ChapterErrorResponse(NestError):
    r"""Chapter error response schema."""

    data: ChapterErrorResponseData

    def __init__(
        self,
        data: ChapterErrorResponseData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.message) or fallback
        super().__init__(message, raw_response, body)
        self.data = data



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .repositoryschema import RepositorySchema, RepositorySchemaTypedDict
from owasp_nest.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PagedRepositorySchemaTypedDict(TypedDict):
    items: List[RepositorySchemaTypedDict]
    count: int


class PagedRepositorySchema(BaseModel):
    items: List[RepositorySchema]

    count: int



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from owasp_nest.types import BaseModel
from typing_extensions import TypedDict


class ReleaseSchemaTypedDict(TypedDict):
    r"""Schema for Release."""

    created_at: datetime
    description: str
    name: str
    published_at: datetime
    tag_name: str


class ReleaseSchema(BaseModel):
    r"""Schema for Release."""

    created_at: datetime

    description: str

    name: str

    published_at: datetime

    tag_name: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .nesterror import NestError
from typing import TYPE_CHECKING
from importlib import import_module
import builtins
import sys

if TYPE_CHECKING:
    from .chaptererrorresponse import ChapterErrorResponse, ChapterErrorResponseData
    from .chapterschema import ChapterSchema, ChapterSchemaTypedDict
    from .committeeschema import CommitteeSchema, CommitteeSchemaTypedDict
    from .eventschema import EventSchema, EventSchemaTypedDict
    from .get_chapterop import GetChapterRequest, GetChapterRequestTypedDict
    from .get_memberop import GetMemberRequest, GetMemberRequestTypedDict
    from .issueschema import IssueSchema, IssueSchemaTypedDict
    from .list_chaptersop import (
        ListChaptersOrdering,
        ListChaptersRequest,
        ListChaptersRequestTypedDict,
    )
    from .list_committeesop import (
        ListCommitteesOrdering,
        ListCommitteesRequest,
        ListCommitteesRequestTypedDict,
    )
    from .list_eventsop import (
        ListEventsOrdering,
        ListEventsRequest,
        ListEventsRequestTypedDict,
    )
    from .list_issuesop import (
        ListIssuesOrdering,
        ListIssuesRequest,
        ListIssuesRequestTypedDict,
    )
    from .list_membersop import (
        ListMembersOrdering,
        ListMembersRequest,
        ListMembersRequestTypedDict,
    )
    from .list_organizationsop import (
        ListOrganizationsOrdering,
        ListOrganizationsRequest,
        ListOrganizationsRequestTypedDict,
    )
    from .list_projectsop import (
        ListProjectsOrdering,
        ListProjectsRequest,
        ListProjectsRequestTypedDict,
    )
    from .list_releasesop import (
        ListReleasesOrdering,
        ListReleasesRequest,
        ListReleasesRequestTypedDict,
    )
    from .list_repositoriesop import (
        ListRepositoriesOrdering,
        ListRepositoriesRequest,
        ListRepositoriesRequestTypedDict,
    )
    from .membererrorresponse import MemberErrorResponse, MemberErrorResponseData
    from .memberschema import MemberSchema, MemberSchemaTypedDict
    from .nestapierror import NestAPIError
    from .no_response_error import NoResponseError
    from .organizationschema import OrganizationSchema, OrganizationSchemaTypedDict
    from .pagedchapterschema import PagedChapterSchema, PagedChapterSchemaTypedDict
    from .pagedcommitteeschema import (
        PagedCommitteeSchema,
        PagedCommitteeSchemaTypedDict,
    )
    from .pagedeventschema import PagedEventSchema, PagedEventSchemaTypedDict
    from .pagedissueschema import PagedIssueSchema, PagedIssueSchemaTypedDict
    from .pagedmemberschema import PagedMemberSchema, PagedMemberSchemaTypedDict
    from .pagedorganizationschema import (
        PagedOrganizationSchema,
        PagedOrganizationSchemaTypedDict,
    )
    from .pagedprojectschema import PagedProjectSchema, PagedProjectSchemaTypedDict
    from .pagedreleaseschema import PagedReleaseSchema, PagedReleaseSchemaTypedDict
    from .pagedrepositoryschema import (
        PagedRepositorySchema,
        PagedRepositorySchemaTypedDict,
    )
    from .projectlevel import ProjectLevel
    from .projectschema import ProjectSchema, ProjectSchemaTypedDict
    from .releaseschema import ReleaseSchema, ReleaseSchemaTypedDict
    from .repositoryschema import RepositorySchema, RepositorySchemaTypedDict
    from .responsevalidationerror import ResponseValidationError
    from .security import Security, SecurityTypedDict
    from .state import State

__all__ = [
    "ChapterErrorResponse",
    "ChapterErrorResponseData",
    "ChapterSchema",
    "ChapterSchemaTypedDict",
    "CommitteeSchema",
    "CommitteeSchemaTypedDict",
    "EventSchema",
    "EventSchemaTypedDict",
    "GetChapterRequest",
    "GetChapterRequestTypedDict",
    "GetMemberRequest",
    "GetMemberRequestTypedDict",
    "IssueSchema",
    "IssueSchemaTypedDict",
    "ListChaptersOrdering",
    "ListChaptersRequest",
    "ListChaptersRequestTypedDict",
    "ListCommitteesOrdering",
    "ListCommitteesRequest",
    "ListCommitteesRequestTypedDict",
    "ListEventsOrdering",
    "ListEventsRequest",
    "ListEventsRequestTypedDict",
    "ListIssuesOrdering",
    "ListIssuesRequest",
    "ListIssuesRequestTypedDict",
    "ListMembersOrdering",
    "ListMembersRequest",
    "ListMembersRequestTypedDict",
    "ListOrganizationsOrdering",
    "ListOrganizationsRequest",
    "ListOrganizationsRequestTypedDict",
    "ListProjectsOrdering",
    "ListProjectsRequest",
    "ListProjectsRequestTypedDict",
    "ListReleasesOrdering",
    "ListReleasesRequest",
    "ListReleasesRequestTypedDict",
    "ListRepositoriesOrdering",
    "ListRepositoriesRequest",
    "ListRepositoriesRequestTypedDict",
    "MemberErrorResponse",
    "MemberErrorResponseData",
    "MemberSchema",
    "MemberSchemaTypedDict",
    "NestAPIError",
    "NestError",
    "NoResponseError",
    "OrganizationSchema",
    "OrganizationSchemaTypedDict",
    "PagedChapterSchema",
    "PagedChapterSchemaTypedDict",
    "PagedCommitteeSchema",
    "PagedCommitteeSchemaTypedDict",
    "PagedEventSchema",
    "PagedEventSchemaTypedDict",
    "PagedIssueSchema",
    "PagedIssueSchemaTypedDict",
    "PagedMemberSchema",
    "PagedMemberSchemaTypedDict",
    "PagedOrganizationSchema",
    "PagedOrganizationSchemaTypedDict",
    "PagedProjectSchema",
    "PagedProjectSchemaTypedDict",
    "PagedReleaseSchema",
    "PagedReleaseSchemaTypedDict",
    "PagedRepositorySchema",
    "PagedRepositorySchemaTypedDict",
    "ProjectLevel",
    "ProjectSchema",
    "ProjectSchemaTypedDict",
    "ReleaseSchema",
    "ReleaseSchemaTypedDict",
    "RepositorySchema",
    "RepositorySchemaTypedDict",
    "ResponseValidationError",
    "Security",
    "SecurityTypedDict",
    "State",
]

_dynamic_imports: dict[str, str] = {
    "ChapterErrorResponse": ".chaptererrorresponse",
    "ChapterErrorResponseData": ".chaptererrorresponse",
    "ChapterSchema": ".chapterschema",
    "ChapterSchemaTypedDict": ".chapterschema",
    "CommitteeSchema": ".committeeschema",
    "CommitteeSchemaTypedDict": ".committeeschema",
    "EventSchema": ".eventschema",
    "EventSchemaTypedDict": ".eventschema",
    "GetChapterRequest": ".get_chapterop",
    "GetChapterRequestTypedDict": ".get_chapterop",
    "GetMemberRequest": ".get_memberop",
    "GetMemberRequestTypedDict": ".get_memberop",
    "IssueSchema": ".issueschema",
    "IssueSchemaTypedDict": ".issueschema",
    "ListChaptersOrdering": ".list_chaptersop",
    "ListChaptersRequest": ".list_chaptersop",
    "ListChaptersRequestTypedDict": ".list_chaptersop",
    "ListCommitteesOrdering": ".list_committeesop",
    "ListCommitteesRequest": ".list_committeesop",
    "ListCommitteesRequestTypedDict": ".list_committeesop",
    "ListEventsOrdering": ".list_eventsop",
    "ListEventsRequest": ".list_eventsop",
    "ListEventsRequestTypedDict": ".list_eventsop",
    "ListIssuesOrdering": ".list_issuesop",
    "ListIssuesRequest": ".list_issuesop",
    "ListIssuesRequestTypedDict": ".list_issuesop",
    "ListMembersOrdering": ".list_membersop",
    "ListMembersRequest": ".list_membersop",
    "ListMembersRequestTypedDict": ".list_membersop",
    "ListOrganizationsOrdering": ".list_organizationsop",
    "ListOrganizationsRequest": ".list_organizationsop",
    "ListOrganizationsRequestTypedDict": ".list_organizationsop",
    "ListProjectsOrdering": ".list_projectsop",
    "ListProjectsRequest": ".list_projectsop",
    "ListProjectsRequestTypedDict": ".list_projectsop",
    "ListReleasesOrdering": ".list_releasesop",
    "ListReleasesRequest": ".list_releasesop",
    "ListReleasesRequestTypedDict": ".list_releasesop",
    "ListRepositoriesOrdering": ".list_repositoriesop",
    "ListRepositoriesRequest": ".list_repositoriesop",
    "ListRepositoriesRequestTypedDict": ".list_repositoriesop",
    "MemberErrorResponse": ".membererrorresponse",
    "MemberErrorResponseData": ".membererrorresponse",
    "MemberSchema": ".memberschema",
    "MemberSchemaTypedDict": ".memberschema",
    "NestAPIError": ".nestapierror",
    "NoResponseError": ".no_response_error",
    "OrganizationSchema": ".organizationschema",
    "OrganizationSchemaTypedDict": ".organizationschema",
    "PagedChapterSchema": ".pagedchapterschema",
    "PagedChapterSchemaTypedDict": ".pagedchapterschema",
    "PagedCommitteeSchema": ".pagedcommitteeschema",
    "PagedCommitteeSchemaTypedDict": ".pagedcommitteeschema",
    "PagedEventSchema": ".pagedeventschema",
    "PagedEventSchemaTypedDict": ".pagedeventschema",
    "PagedIssueSchema": ".pagedissueschema",
    "PagedIssueSchemaTypedDict": ".pagedissueschema",
    "PagedMemberSchema": ".pagedmemberschema",
    "PagedMemberSchemaTypedDict": ".pagedmemberschema",
    "PagedOrganizationSchema": ".pagedorganizationschema",
    "PagedOrganizationSchemaTypedDict": ".pagedorganizationschema",
    "PagedProjectSchema": ".pagedprojectschema",
    "PagedProjectSchemaTypedDict": ".pagedprojectschema",
    "PagedReleaseSchema": ".pagedreleaseschema",
    "PagedReleaseSchemaTypedDict": ".pagedreleaseschema",
    "PagedRepositorySchema": ".pagedrepositoryschema",
    "PagedRepositorySchemaTypedDict": ".pagedrepositoryschema",
    "ProjectLevel": ".projectlevel",
    "ProjectSchema": ".projectschema",
    "ProjectSchemaTypedDict": ".projectschema",
    "ReleaseSchema": ".releaseschema",
    "ReleaseSchemaTypedDict": ".releaseschema",
    "RepositorySchema": ".repositoryschema",
    "RepositorySchemaTypedDict": ".repositoryschema",
    "ResponseValidationError": ".responsevalidationerror",
    "Security": ".security",
    "SecurityTypedDict": ".security",
    "State": ".state",
}


def dynamic_import(modname, retries=3):
    for attempt in range(retries):
        try:
            return import_module(modname, __package__)
        except KeyError:
            # Clear any half-initialized module and retry
            sys.modules.pop(modname, None)
            if attempt == retries - 1:
                break
    raise KeyError(f"Failed to import module '{modname}' after {retries} attempts")


def __getattr__(attr_name: str) -> object:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(
            f"No {attr_name} found in _dynamic_imports for module name -> {__name__} "
        )

    try:
        module = dynamic_import(module_name)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(
            f"Failed to import {attr_name} from {module_name}: {e}"
        ) from e
    except AttributeError as e:
        raise AttributeError(
            f"Failed to get {attr_name} from {module_name}: {e}"
        ) from e


def __dir__():
    lazy_attrs = builtins.list(_dynamic_imports.keys())
    return builtins.sorted(lazy_attrs)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .releaseschema import ReleaseSchema, ReleaseSchemaTypedDict
from owasp_nest.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PagedReleaseSchemaTypedDict(TypedDict):
    items: List[ReleaseSchemaTypedDict]
    count: int


class PagedReleaseSchema(BaseModel):
    items: List[ReleaseSchema]

    count: int



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .committeeschema import CommitteeSchema, CommitteeSchemaTypedDict
from owasp_nest.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PagedCommitteeSchemaTypedDict(TypedDict):
    items: List[CommitteeSchemaTypedDict]
    count: int


class PagedCommitteeSchema(BaseModel):
    items: List[CommitteeSchema]

    count: int



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from owasp_nest.types import BaseModel
from typing_extensions import TypedDict


class EventSchemaTypedDict(TypedDict):
    r"""Schema for Event."""

    description: str
    name: str
    end_date: datetime
    start_date: datetime
    url: str


class EventSchema(BaseModel):
    r"""Schema for Event."""

    description: str

    name: str

    end_date: datetime

    start_date: datetime

    url: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .projectschema import ProjectSchema, ProjectSchemaTypedDict
from owasp_nest.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PagedProjectSchemaTypedDict(TypedDict):
    items: List[ProjectSchemaTypedDict]
    count: int


class PagedProjectSchema(BaseModel):
    items: List[ProjectSchema]

    count: int



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from owasp_nest.types import BaseModel
from owasp_nest.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class GetMemberRequestTypedDict(TypedDict):
    login: str


class GetMemberRequest(BaseModel):
    login: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .projectlevel import ProjectLevel
from datetime import datetime
from owasp_nest.types import BaseModel
from typing_extensions import TypedDict


class ProjectSchemaTypedDict(TypedDict):
    r"""Schema for Project."""

    created_at: datetime
    description: str
    level: ProjectLevel
    r"""Enum for OWASP project levels."""
    name: str
    updated_at: datetime


class ProjectSchema(BaseModel):
    r"""Schema for Project."""

    created_at: datetime

    description: str

    level: ProjectLevel
    r"""Enum for OWASP project levels."""

    name: str

    updated_at: datetime



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .chapterschema import ChapterSchema, ChapterSchemaTypedDict
from owasp_nest.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PagedChapterSchemaTypedDict(TypedDict):
    items: List[ChapterSchemaTypedDict]
    count: int


class PagedChapterSchema(BaseModel):
    items: List[ChapterSchema]

    count: int



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .issueschema import IssueSchema, IssueSchemaTypedDict
from owasp_nest.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PagedIssueSchemaTypedDict(TypedDict):
    items: List[IssueSchemaTypedDict]
    count: int


class PagedIssueSchema(BaseModel):
    items: List[IssueSchema]

    count: int



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .state import State
from enum import Enum
from owasp_nest.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from owasp_nest.utils import FieldMetadata, QueryParamMetadata
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ListIssuesOrdering(str, Enum):
    r"""Ordering field"""

    CREATED_AT = "created_at"
    MINUS_CREATED_AT = "-created_at"
    UPDATED_AT = "updated_at"
    MINUS_UPDATED_AT = "-updated_at"


class ListIssuesRequestTypedDict(TypedDict):
    state: NotRequired[Nullable[State]]
    r"""State of the issue"""
    ordering: NotRequired[Nullable[ListIssuesOrdering]]
    r"""Ordering field"""
    page: NotRequired[int]
    page_size: NotRequired[Nullable[int]]


class ListIssuesRequest(BaseModel):
    state: Annotated[
        OptionalNullable[State],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""State of the issue"""

    ordering: Annotated[
        OptionalNullable[ListIssuesOrdering],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Ordering field"""

    page: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 1

    page_size: Annotated[
        OptionalNullable[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["state", "ordering", "page", "page_size"]
        nullable_fields = ["state", "ordering", "page_size"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .organizationschema import OrganizationSchema, OrganizationSchemaTypedDict
from owasp_nest.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PagedOrganizationSchemaTypedDict(TypedDict):
    items: List[OrganizationSchemaTypedDict]
    count: int


class PagedOrganizationSchema(BaseModel):
    items: List[OrganizationSchema]

    count: int



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .eventschema import EventSchema, EventSchemaTypedDict
from owasp_nest.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PagedEventSchemaTypedDict(TypedDict):
    items: List[EventSchemaTypedDict]
    count: int


class PagedEventSchema(BaseModel):
    items: List[EventSchema]

    count: int



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from owasp_nest.types import BaseModel
from typing_extensions import TypedDict


class OrganizationSchemaTypedDict(TypedDict):
    r"""Schema for Organization."""

    company: str
    created_at: datetime
    location: str
    login: str
    name: str
    updated_at: datetime


class OrganizationSchema(BaseModel):
    r"""Schema for Organization."""

    company: str

    created_at: datetime

    location: str

    login: str

    name: str

    updated_at: datetime



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from owasp_nest.types import BaseModel
from typing_extensions import TypedDict


class ChapterSchemaTypedDict(TypedDict):
    r"""Schema for Chapter."""

    country: str
    created_at: datetime
    name: str
    region: str
    updated_at: datetime


class ChapterSchema(BaseModel):
    r"""Schema for Chapter."""

    country: str

    created_at: datetime

    name: str

    region: str

    updated_at: datetime
